package Chart::Plotly::Trace::Attribute::Xbins;
use Moose;

our $VERSION = '0.007';    # VERSION

=encoding utf-8

=head1 NAME 

Chart::Plotly::Trace::Attribute::Xbins

=head1 SYNOPSIS

	use HTML::Show;
	use Chart::Plotly;
	use Chart::Plotly::Trace::Attribute::Xbins;
	my $xbins = Chart::Plotly::Trace::Attribute::Xbins->new(x => [1 .. 5], y => [1 .. 5]);
	
	HTML::Show::show(Chart::Plotly::render_full_html(data => [$xbins]));


=head1 DESCRIPTION

This file has been autogenerated from the official plotly.js source.

If you like Plotly, please support them: L<https://plot.ly/> 
Open source announcement: L<https://plot.ly/javascript/open-source-announcement/>

Full reference: L<https://plot.ly/javascript/reference/#xbins>

=head1 DISCLAIMER

This is an unofficial Plotly Perl module. Currently I'm not affiliated in any way with Plotly. 
But I think plotly.js is a great library and I want to use it with perl.

=head1 METHODS

=cut

=head2 TO_JSON

Serialize the trace to JSON. This method should be called only by L<JSON> serializer.

=cut

sub TO_JSON {
    my $self = shift;
    my %hash = %$self;
    if ( $self->can('type') && ( !defined $hash{'type'} ) ) {
        $hash{type} = $self->type();
    }
    return \%hash;
}

=head1 ATTRIBUTES

=over

=cut

=item * end

Sets the end value for the x axis bins.

=cut

has end => ( is            => 'rw',
             isa           => "Any",
             documentation => "Sets the end value for the x axis bins.",
);

=item * size

Sets the step in-between value each x axis bin.

=cut

has size => ( is            => 'rw',
              isa           => "Any",
              documentation => "Sets the step in-between value each x axis bin.",
);

=item * start

Sets the starting value for the x axis bins.

=cut

has start => ( is            => 'rw',
               isa           => "Any",
               documentation => "Sets the starting value for the x axis bins.",
);

=item * name

Sets the trace name

=cut

has name => ( is            => 'rw',
              isa           => "Str",
              documentation => "Sets the trace name",
);

=pod

=back

=cut

__PACKAGE__->meta->make_immutable();
1;
